/**
 * ModServ IRC Services
 * Version 2009
 * Copyright (C) 2007, 2008 Christian Jurk <commx@commx.ws>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License,
 * or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __MS_MAIN_H
#define __MS_MAIN_H

#include <QApplication>
#include <QDateTime>
#include <QString>
#include <MS_Configreader.h>
#include <MS_Log.h>
#include <MS_Networking.h>

#define USE_P10 /* define this for P10 compatible protocol handling */

#ifdef USE_P10
#include <MS_P10_Parser.h>
#endif

class MMainInstance {
  private:
    QApplication *m_application;
    QDateTime m_bootTime;
    QString m_strConfigFile;
    QString m_strLogFile;
    QString m_builtTime;

  public:
    MMainInstance();
    void setApplication(QApplication *psrc);
    QApplication *getApplication(void);
    void parseArguments(void);
    void setConfigFile(const QString &strFile);
    const QString &getConfigFile(void);
    void setLogFile(const QString &strFile);
    const QString &getLogFile(void);
    void printUsage(const QString &strExec);
    void printVersion(void);
    void setBootTime(const QDateTime &timestamp);
    const QDateTime &getBootTime(void);
    QString randomKey(const quint16 &length);
    void init(void);
    const QString &getBuilt(void);
    
    MConfigReader *config;
    MTcpSocket *socket;
    MLog *log;
#ifdef USE_P10
    MP10Parser *parser;
#endif
};

extern MMainInstance *globalMain;

#endif /* __MS_MAIN_H */
