/**
 * ModServ IRC Services
 * Version 2009
 * Copyright (C) 2007, 2008 Christian Jurk <commx@commx.ws>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License,
 * or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __MS_USER_H
#define __MS_USER_H

#include <QtGlobal>
#include <QString>
#include <QStringList>
#include <QDateTime>
#include <QHostAddress>
#include <QList>
#include <MS_Servers.h>
#include <MS_Flagops.h>

class MChannel;

class MUser {
  private:
    QString m_nick;
    QString m_ident;
    QString m_account;
    QDateTime m_connected;
    QDateTime m_nickTime;
    QString m_host;
    quint32 m_modeflags;
    unsigned int m_numeric;
    MServer *m_server;
    QList<MChannel *> m_channelList;
    
  public:
    MUser(const QString &strNick = QString(""));
    ~MUser();
    void setNick(const QString &strNick);
    void setIdent(const QString &strIdent);
    void setHostname(const QString &strHost);
    void setAccount(const QString &strAccount);
    void setConnectedAt(const QDateTime &timestamp);
    void setNicktime(const QDateTime &timestamp);
    void setModeflags(const quint32 &flags);
    void setNumeric(const unsigned int &num);
    void setServer(MServer *srv = 0);
    
    const QString &nick(void);
    const QString &ident(void);
    const QString &account(void);
    const QString &hostname(void);
    const QDateTime &connectedAt(void);
    const QDateTime &nicktime(void);
    const quint32 &modeflags(void);
    const unsigned int &numeric(void);
    QString numeric64(void);
    MServer *server(void);
    void addChannel(MChannel *chan);
    void removeChannel(MChannel *chan);
    QList<MChannel *> channelList(void);
    bool isAuthed(void);
    bool isOper(void);

    static quint32 parseModeflags(const QString &strFlags);
    static QString buildModeflagstr(const quint32 &flags);
    static void init(void);
    static MUser *findByNick(const QString &strNick);
    static MUser *find(unsigned int num);

    const static int Flag_Admin = 0x001;
    const static int Flag_Deaf = 0x002;
    const static int Flag_Debug = 0x004;
    const static int Flag_Sethost = 0x008;
    const static int Flag_Invisible = 0x010;
    const static int Flag_Chanserv = 0x020;
    const static int Flag_Operator = 0x040;
    const static int Flag_Account = 0x080;
    const static int Flag_Noanonymous = 0x100;
    const static int Flag_Wallops = 0x200;
    const static int Flag_Hiddenhost = 0x400;
};

extern QHash<unsigned int, MUser *> userList;
extern QHash<QString, MUser *> nickList;
extern QHash<char, quint32> umodeList;

#endif /* __MS_USERS_H */
