/**
 * ModServ IRC Services
 * Version 2009
 * Copyright (C) 2007, 2008 Christian Jurk <commx@commx.ws>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License,
 * or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#include <iostream>
#include <cstdlib>
#include <QApplication>
#include <QStringList>
#include <QFile>
#include <QTextStream>
#include <MS_Configreader.h>
#include <MS_Main.h>
#include <MS_Dl.h>

MConfigReader::MConfigReader(const QString &strConfigFile) {
  readFile(strConfigFile);
}

void MConfigReader::readFile(const QString &strFile) {
  QFile myFile(strFile);

  if (!myFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
    QString strMsg = QString("MConfigReader: Unable to read configuration \"%1\"").arg(strFile);
    globalMain->log->print(L_FATAL, strMsg);
  }

  QTextStream stream(&myFile);
  while(!stream.atEnd()) {
    QString strLine = stream.readLine();
    if (strLine.contains("=") && strLine.left(1) != QString("#")) {
      QStringList strlEx = strLine.split("=");
      set(strlEx.at(0).trimmed(), strlEx.at(1).trimmed());
    } else if (strLine.left(8) == QString("Include ")) {
      readFile(strLine.mid(8));
    } else if (strLine.left(11) == QString("LoadModule ")) {
      m_moduleList << strLine.mid(11);
    }
  }
  
  myFile.close();
}

QString MConfigReader::get(QString strKey, QString strDefaultValue) {
  if (!m_hashItems.contains(strKey))
    return strDefaultValue;
    
  return m_hashItems.value(strKey);
}

void MConfigReader::set(QString strKey, QString strValue) {
  m_hashItems.insert(strKey, strValue);
}

QStringList MConfigReader::getModuleList(void) {
  return m_moduleList;
}
