/**
 * ModServ IRC Services
 * Version 2009
 * Copyright (C) 2007, 2008 Christian Jurk <commx@commx.ws>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License,
 * or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#include <iostream>
#include <cstdlib>
#include <QDateTime>
#include <MS_Log.h>

MLog::MLog(const QString &strFile) {
  if (!strFile.isEmpty()) {
    m_file.setFileName(strFile);
  
    if (!m_file.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text)) {
      std::cout << "MLog: Unable to open log file: " << strFile.toStdString() << std::endl;
      return;
    }
  
    m_file.write(QString("Session opened.\n").toLatin1());
    m_file.flush();
    m_opened = true;
  } else {
    m_opened = false;
  }
}

MLog::~MLog() {
  close();
}

void MLog::close(void) {
  if (m_opened) {
    m_file.write(QString("Session close.\n").toLatin1());
    m_file.flush();
    m_file.close();
  }
}

void MLog::print(quint32 flags, const QString &strIn) {
  QDateTime dateTime = QDateTime::currentDateTime();
  QString strPrepare, strWhat;
  
  if (flags & L_NOTICE)
    strWhat = "Notice";
  if (flags & L_WARN)
    strWhat = "Warning";
  if (flags & L_ERR)
    strWhat = "Error";
  if (flags & L_FATAL)
    strWhat = "FATAL";
  
  strPrepare = QString("(%1) {%2} %3\n").arg(dateTime.toString("hhmmss")).arg(strWhat).arg(strIn);
  
  if (m_opened) {
    m_file.write(strPrepare.toStdString().c_str(), strPrepare.length());
    m_file.flush();
  }
    
  std::cout << strPrepare.toStdString();
  
  if (flags & L_FATAL && m_opened) {
    strPrepare = QString("Fatal error encountered, exiting.\n");
    m_file.write(strPrepare.toStdString().c_str(), strPrepare.length());
    m_file.flush();
    close();
    std::exit(1);
  }
}
